aboutsummaryrefslogtreecommitdiff
path: root/packages/server/src/git/misc.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/server/src/git/misc.ts')
-rw-r--r--packages/server/src/git/misc.ts6
1 files changed, 3 insertions, 3 deletions
diff --git a/packages/server/src/git/misc.ts b/packages/server/src/git/misc.ts
index da9b1ee..1fda304 100644
--- a/packages/server/src/git/misc.ts
+++ b/packages/server/src/git/misc.ts
@@ -17,13 +17,13 @@ export async function findAsync<T>(arr: T[], callback: (t: T) => Promise<boolean
/**
* Returns the content of a file inside a repository
*
* @param base_dir - The directory which the repository is in
* @param repository - The directory of a bare repository
* @param file - The path of a file
*/
-export function getFile(base_dir: string, repository: string, file: string): Promise<string> {
+export function getFile(git_dir: string, repository: string, file: string): Promise<string> {
return new Promise((resolve, reject) => {
- readFile(`${base_dir}/${repository}/${file}`, (err, content) => {
+ readFile(`${git_dir}/${repository}/${file}`, (err, content) => {
if(err) {
reject(createError(MiscError, 500, "Failed to open repository file " + file));
return;
@@ -17,13 +17,13 @@ export async function findAsync<T>(arr: T[], callback: (t: T) => Promise<boolean
* Returns the content of a file inside a repository
*
- * @param base_dir - The directory which the repository is in
+ * @param git_dir - The directory which the repository is in
* @param repository - The directory of a bare repository
* @param file - The path of a file